@@ -18,20 +18,19 @@ from zope.testing import doctest, renormalizing
 
 try:
     import pkg_resources
-except ImportError:
-    zdaemon_loc = os.path.dirname(os.path.dirname(zdaemon.__file__))
-    zconfig_loc = os.path.dirname(os.path.dirname(ZConfig.__file__))
-else:
     zdaemon_loc = pkg_resources.working_set.find(
         pkg_resources.Requirement.parse('zdaemon')).location
     zconfig_loc = pkg_resources.working_set.find(
         pkg_resources.Requirement.parse('ZConfig')).location
+except (ImportError, AttributeError):
+    zdaemon_loc = os.path.dirname(os.path.dirname(zdaemon.__file__))
+    zconfig_loc = os.path.dirname(os.path.dirname(ZConfig.__file__))
 
 
 def make_sure_non_daemon_mode_doesnt_hang_when_program_exits():
     """
     The whole awhile bit that waits for a program to start
-    whouldn't be used on non-daemopn mode.
+    whouldn't be used on non-daemon mode.
 
     >>> open('conf', 'w').write(
     ... '''
@@ -58,14 +57,14 @@ def dont_hang_when_program_doesnt_start():
     ... ''')
 
     >>> system("./zdaemon -Cconf start")
-    . . 
-    Daemon manager not running.
+    . .
+    daemon manager not running
 
     """
-    
+
 def allow_duplicate_arguments():
     """
-    
+
 Wrapper scripts will often embed configuration arguments. This could
 cause a problem when zdaemon reinvokes itself, passing it's own set of
 configuration arguments.  To deal with this, we'll allow duplicate
@@ -79,9 +78,11 @@ arguments that have the same values.
     ... ''')
 
     >>> system("./zdaemon -Cconf -Cconf -Cconf start")
-    . daemon process started, pid=21446
+    . .
+    daemon process started, pid=21446
 
     >>> system("./zdaemon -Cconf -Cconf -Cconf stop")
+    . .
     daemon process stopped
 
 """
@@ -90,6 +91,9 @@ def setUp(test):
     test.globs['_td'] = td = []
     here = os.getcwd()
     td.append(lambda : os.chdir(here))
+    tmpdir = tempfile.mkdtemp()
+    td.append(lambda : shutil.rmtree(tmpdir))
+    test.globs['tmpdir'] = tmpdir
     workspace = tempfile.mkdtemp()
     td.append(lambda : shutil.rmtree(workspace))
     os.chdir(workspace)
@@ -127,6 +131,7 @@ def test_suite():
             setUp=setUp, tearDown=tearDown,
             checker=renormalizing.RENormalizing([
                 (re.compile('pid=\d+'), 'pid=NNN'),
+                (re.compile('(\. )+\.?'), '<BLANKLINE>'),
                 ])
         ),
         doctest.DocFileSuite(
@@ -134,6 +139,7 @@ def test_suite():
             setUp=setUp, tearDown=tearDown,
             checker=renormalizing.RENormalizing([
                 (re.compile('pid=\d+'), 'pid=NNN'),
+                (re.compile('(\. )+\.?'), '<BLANKLINE>'),
                 (re.compile('^env\n((?:.*\n)+)$'), checkenv),
                 ])
         ),
