@@ -16,7 +16,7 @@
 
 Usage: python zdctl.py [-C URL] [-S schema.xml] [-h] [-p PROGRAM]
        [zdrun-options] [action [arguments]]
-
+ 
 Options:
 -C/--configure URL -- configuration file or URL
 -S/--schema XML Schema -- XML schema for configuration file
@@ -43,6 +43,7 @@ action "help" to find out about available actions.
 """
 
 import os
+import os.path
 import re
 import cmd
 import sys
@@ -75,7 +76,9 @@ def string_list(arg):
 
 
 class ZDCtlOptions(RunnerOptions):
-
+    
+    __doc__ = __doc__
+    
     positional_args_allowed = True
 
     def __init__(self):
@@ -99,6 +102,7 @@ class ZDCtlOptions(RunnerOptions):
         self.add("prompt", "runner.prompt", default=(programname + ">"))
 
     def realize(self, *args, **kwds):
+        
         RunnerOptions.realize(self, *args, **kwds)
 
         # Maybe the config file requires -i or positional args
@@ -128,21 +132,46 @@ class ZDCmd(cmd.Cmd):
             if m:
                 s = m.group(1)
                 args = eval(s, {"__builtins__": {}})
-                program = self.options.program 
+                program = self.options.program
                 if args[:len(program)] != program:
                     print "WARNING! zdrun is managing a different program!"
                     print "our program   =", program
                     print "daemon's args =", args
 
-        if (options.configroot is not None
-            and
-            getattr(options.configroot, 'environment', None) is not None
-            ):
-            for k, v in options.configroot.environment.mapping.items():
-                os.environ[k] = v
+        if options.configroot is not None:
+            env = getattr(options.configroot, 'environment', None)
+            if env is not None:
+                if getattr(env, 'mapping', None) is not None:
+                    for k, v in env.mapping.items():
+                        os.environ[k] = v
+                elif type(env) is type({}):
+                    for k, v in env.items():
+                        os.environ[k] = v
 
+        self.create_rundir()
+        self.create_socket_dir()
         self.set_uid()
 
+    def create_rundir(self):
+        if self.options.directory is None:
+            return
+        self.create_directory(self.options.directory)
+
+    def create_socket_dir(self):
+        dir = os.path.dirname(self.options.sockname)
+        if not dir:
+            return
+        self.create_directory(dir)
+
+    def create_directory(self, directory):
+        if os.path.isdir(directory):
+            return
+        os.mkdir(directory)
+        uid = os.geteuid()
+        if uid == 0 and uid != self.options.uid:
+            # Change owner of directory to target
+            os.chown(directory, self.options.uid, self.options.gid)
+
     def set_uid(self):
         if self.options.uid is None:
             return
@@ -195,11 +224,11 @@ class ZDCmd(cmd.Cmd):
 
     def awhile(self, cond, msg):
         n = 0
-        was_running = True
+        was_running = False
         try:
             if self.get_status():
                 was_running = True
-                
+
             while not cond():
                 sys.stdout.write(". ")
                 sys.stdout.flush()
@@ -207,14 +236,14 @@ class ZDCmd(cmd.Cmd):
                 n += 1
                 if self.get_status():
                     was_running = True
-                elif was_running or n > 10:
-                    print "\nDaemon manager not running."
+                elif (was_running or n > 10) and not cond():
+                    print "\ndaemon manager not running"
                     return
 
         except KeyboardInterrupt:
             print "^C"
-        else:
-            print msg % self.__dict__
+        print "\n" + msg % self.__dict__
+
 
     def help_help(self):
         print "help          -- Print a list of available actions."
@@ -235,7 +264,7 @@ class ZDCmd(cmd.Cmd):
             else:
                 args = [self.options.python, sys.argv[0]]
                 os.environ['DAEMON_MANAGER_MODE'] = '1'
-                
+
             args += self._get_override("-S", "schemafile")
             args += self._get_override("-C", "configfile")
             args += self._get_override("-b", "backofflimit")
@@ -619,7 +648,7 @@ def main(args=None, options=None, cmdclass=ZDCmd):
     if os.environ.get('DAEMON_MANAGER_MODE'):
         import zdaemon.zdrun
         return zdaemon.zdrun.main(args)
-        
+
     if options is None:
         options = ZDCtlOptions()
     options.realize(args)
